#!/usr/bin/env python

__author__ = 'david.johnnes@gmail.com'

"""
This Script will be used to establish SSH connection.
"""

import paramiko
import time
import subprocess
import os
import getpass

un_reachable_hosts = []


def ssh_connector(user_name, pass_word, host_name):
    """ """
    ENTER = "\n"
    ssh = paramiko.SSHClient()

    try:
        ssh.set_missing_host_key_policy(paramiko.AutoAddPolicy())
        ssh.connect(hostname=host_name, username=user_name, password=pass_word, look_for_keys=False, port=22)
        print("connected to {0}\n".format(host_name))
        time.sleep(4)
    except:  # Record unreachable hosts in a list
        print("Could not connect to >> {}".format(host_name))
        ssh.close()
        exit()
    else:
        #  Create a channel to send commands to the host
        channel = ssh.invoke_shell()
        print("Starting the channel !!!\n")

        channel.send("show lldp info re")
        channel.send(ENTER)
        time.sleep(4)

        output = channel.recv(9999)
        time.sleep(6)
        print(output)
        channel.close()
        ssh.close()
        return output


#  This function is used to check and use the .sshpass as default authentication password
def get_sshpass_pwd():
    """ """
    home_path = os.environ["HOME"]
    os.chdir(home_path)

    file = subprocess.Popen(["ls", "-a"], stdin=subprocess.PIPE, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
    output = file.communicate()[0]
    output = output.decode()

    if ".sshpass" in output:
        password = subprocess.Popen(["cat", ".sshpass"], stdout=subprocess.PIPE)
        password = password.communicate()[0]
        password = password.decode()
        return password.strip()
    else:
        print("Can not use the script. Need sshpass file.")
        exit()


def save_to_file(data):
    file = open("temp_file", "w")
    file.write(data)


def main(hostname):
    """ """

    user_name = getpass.getuser()
    pass_word = get_sshpass_pwd()
    output = ssh_connector(user_name, pass_word, hostname)
    save_to_file(output)

    print("\n\nSaving the data to file.............")
    time.sleep(4)



#!/usr/bin/env python

__author__ = 'david.johnnes@gmail.com'


class APGenRobot(object):

    def __init__(self, filename, parent_name):
        """ """
        self.filename = filename  # filename must be a .txt file
        self.parent_name = parent_name
        self.base_list = []
        self.splited_list = []
        self.clean_interfaces = []

    def string_cleaner(self):
        with open(self.filename) as file:
            for line in file:
                line = line.strip()

                if "-AP-" in line:
                    line = line.replace("|", "")  # remove the |
                    self.base_list.append(line)

    def file_spliter(self):
        for line in self.base_list:
            splited_line = line.split()

            if len(splited_line) == 3:
                self.splited_list.append(splited_line)

    def make_strings(self):
        for line in self.splited_list:
            hostname = line[1]
            local_port = "interface G0"
            parent_port = line[0]
            interface = [hostname, "config t", local_port,
                         "description {0}({1})".format(self.parent_name, parent_port), "end", "wr me", "exit"]
            self.clean_interfaces.append(interface)

    def show_interfaces(self):
        for line in self.clean_interfaces:
            print(line)

    def generator(self):
        self.string_cleaner()
        self.file_spliter()
        self.make_strings()
        return self.clean_interfaces



#!/usr/bin/env python

__author__ = 'david.johnnes@gmail.com'

"""
This Script will be used to establish SSH connection.
"""

import paramiko
import time
import subprocess
import os
import getpass

un_reachable_hosts = []


def get_sshpass_pwd():
    """ """
    home_path = os.environ["HOME"]
    os.chdir(home_path)

    file = subprocess.Popen(["ls", "-a"], stdin=subprocess.PIPE, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
    output = file.communicate()[0]
    output = output.decode()

    if ".sshpass" in output:
        password = subprocess.Popen(["cat", ".sshpass"], stdout=subprocess.PIPE)
        password = password.communicate()[0]
        password = password.decode()
        return password.strip()
    else:
        print("Can not use the script. Need sshpass file.")
        exit()


def ssh_ap_rename(host_name, user_name, pass_word, commands):
    """This is function is used to connect to an AP and rename the interfaces"""

    ENTER = "\n"
    ssh = paramiko.SSHClient()

    try:
        ssh.set_missing_host_key_policy(paramiko.AutoAddPolicy())
        ssh.connect(hostname=host_name, username=user_name, password=pass_word, look_for_keys=False, port=22)
        print("connected to {0}\n".format(host_name))

    except:  # Record unreachable hosts in a list
        un_reachable_hosts.append(host_name)
        print("could not connect to {}".format(host_name))
        ssh.close()
    else:
        #  Create a channel to send commands to the host
        channel = ssh.invoke_shell()

        for cmd in commands:
            channel.send(cmd)
            channel.send(ENTER)
            time.sleep(4)

            read_output = channel.recv(9999)
            time.sleep(6)
            print(read_output)

        print("=" * 100)
        print()

        channel.close()
        ssh.close()


def rename_aps(data):

    print("\n\nStarting the login process !!!\n\n")
    user_name = getpass.getuser()
    pass_word = get_sshpass_pwd()

    for line in data:
        host_name = line[0]
        commands = line[1:]
        ssh_ap_rename(host_name, user_name, pass_word, commands)

    print("\nRenaming Completed !!\n".upper())




















#!/usr/bin/env python

__author__ = 'david.johnnes@gmail.com'


class HPGenRobot(object):
    """"""

    def __init__(self, filename):
        """ """
        self.filename = filename  # filename must be a .txt file
        self.base_lines = []
        self.splited_list = []
        self.clean_interfaces = ["conf t"]

    def string_cleaner(self):
        with open(self.filename) as file:
            for line in file:
                line = line.strip()

                if "-AP-" in line:
                    line = line.replace("|", "")  # remove the |
                    self.base_lines.append(line)

    def file_spliter(self):
        for line in self.base_lines:
            splited_line = line.split()

            if len(splited_line) == 3:
                self.splited_list.append(splited_line)
            else:
                print("Bad data passed to the file_spliter() !!\n")
                break

    def make_strings(self):
        for line in self.splited_list:
            local_port = line[0]
            remote_host = line[1]

            new_interfaces = "interface {0} name {1}(G0)".format(local_port, remote_host)
            self.clean_interfaces.append(new_interfaces)

    def add_commands(self):
        self.clean_interfaces.append("end")
        self.clean_interfaces.append("wr me")
        self.clean_interfaces.append("logo")
        self.clean_interfaces.append("y")

    def show_interfaces(self):
        for line in self.clean_interfaces:
            print(line)

    def generator(self):
        self.string_cleaner()
        self.file_spliter()
        self.make_strings()
        self.add_commands()
        return self.clean_interfaces



#!/usr/bin/env python
__author__ = 'david.johnnes@gmail.com'

from juraHP import master_connector
from juraHP import ap_generator
from juraHP import ap_connector
from juraHP import hp_generator
from juraHP import hp_connector

""" """


def generate_ap_data(parent_switch):
    """ """
    client = ap_generator.APGenRobot("temp_file", parent_switch)
    output = client.generator()
    client.show_interfaces()
    print("\n")
    return output


def generate_hp_data():
    """ """
    client = hp_generator.HPGenRobot("temp_file")
    output = client.generator()
    client.show_interfaces()
    print("\n")
    return output

print("#" * 110)


def run_rename():
    """ """
    parent_switch = raw_input("Enter parent switch: ")
    master_connector.main(parent_switch)

    ap_data = generate_ap_data(parent_switch)
    ap_connector.rename_aps(ap_data)

    commands = generate_hp_data()
    hp_connector.ssh_hp_rename(parent_switch, commands)

if __name__ == "__main__":
    run_rename()






#!/usr/bin/env python

__author__ = 'david.johnnes@gmail.com'

"""
This Script will be used to establish SSH connection.
"""

import paramiko
import time
import subprocess
import os
import getpass


def get_sshpass_pwd():
    get_my_home_path = os.environ["HOME"]
    os.chdir(get_my_home_path)

    find_sshpass_file = subprocess.Popen(["ls", "-a"], stdin=subprocess.PIPE,
                                         stdout=subprocess.PIPE, stderr=subprocess.PIPE)

    out_put = find_sshpass_file.communicate()[0]
    out_put = out_put.decode()

    if ".sshpass" in out_put:
        my_pass_word = subprocess.Popen(["cat", ".sshpass"], stdout=subprocess.PIPE)
        my_pass_word = my_pass_word.communicate()[0]
        clean_pass_word = my_pass_word.decode()
        return clean_pass_word.strip()
    else:
        print("Can not use the script. Need sshpass file.")
        exit()


def ssh_hp_rename(host_name, commands):
    """This is function is used to connect to an AP and rename the interfaces"""
    ENTER = "\n"
    user_name = getpass.getuser()
    pass_word = get_sshpass_pwd()
    ssh = paramiko.SSHClient()

    try:
        ssh.set_missing_host_key_policy(paramiko.AutoAddPolicy())
        ssh.connect(hostname=host_name, username=user_name, password=pass_word, look_for_keys=False, port=22)
        print("connected to {0}\n".format(host_name))

    except:  # Record unreachable hosts in a list
        print("could not connect to {}".format(host_name))
        ssh.close()
    else:
        #  Create a channel to send commands to the host
        channel = ssh.invoke_shell()

        for cmd in commands:
            channel.send(cmd)
            channel.send(ENTER)
            time.sleep(2)

            read_output = channel.recv(9999)
            time.sleep(4)
            print(read_output)

        print("=" * 100)
        print()
        print("HP-SW ::::  Renaming Completed !!\n".upper())

        channel.close()
        ssh.close()




import setuptools


with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name='juraHP',
    version='1.0',
    url="https://johnnes-smarts.ch",
    license='License :: OSI Approved :: MIT License',
    author='David Johnnes',
    author_email='david.johnnes@gmail.com',
    description='SSH Client Framework for HP/Cisco AeroNet Interface Renaming',
    long_description=long_description,
    long_description_content_type="text/markdown",
    keywords='SSH Client, Network Automation',
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)
